trout <- read.table("http://www.wright.edu/~dvoss/bookdata/txt/trout.txt", header=TRUE)
trout$SULFA <- factor(trout$SULFA)
aov1 <- aov(HEMO ~ SULFA, data=trout) #note: oneway.test(HEMO~SULFA,data=trout,var.equal=TRUE) 
summary(aov1)
            # Df Sum Sq Mean Sq F value  Pr(>F)   
# SULFA        3  26.80   8.934   5.696 0.00268 **
# Residuals   36  56.47   1.569  

# The low p-value provides strong evidence that the mean level of hemoglobin differs between the sulfamerazine groups.

aggregate(HEMO ~ SULFA, data=trout, mean)
  # SULFA HEMO
# 1     1 7.20
# 2     2 9.33
# 3     3 9.03
# 4     4 8.69

boxplot(HEMO~SULFA,data=trout)
# one-way anova

plot(aov1) # returns 4 plots

#test of normality 
# global
shapiro.test(trout$HEMO)

# within each treatment group
with(trout, tapply(HEMO,SULFA,shapiro.test))

# rule of thumb for equal variance: ratio should be less than 3 or 4
tvars <- with(trout, tapply(HEMO,SULFA,var))
max(tvars)/min(tvars)
#[1] 2.943834

#test of equal variance
bartlett.test(HEMO~SULFA,data=trout)


## if Violations of assumptions, non-parametric test: whether samples originate from the same distribution
kruskal.test(HEMO~SULFA,data=trout)

#T-test: just for illustration
trout_1=subset(trout,SULFA<=2)
#equal variance
t.test(HEMO~SULFA,data=trout_1,var.equal=TRUE)

#unequal variance
t.test(HEMO~SULFA,data=trout_1,var.equal=FALSE)

# paired-sample t test: when the samples are dependent, e.g. comparison of pre and post treatment outcome
t.test(, paired=TRUE)

# one-sided t test
t.test(, alternative="less")
t.test(, alternative="greater")
t.test(, alternative="two.sided") #default


## power analysis
library(pwr)
# with the option of alternative="greater" too
# k Number of groups # n Number of observations (per group) # d Effect size ??
# detail for effect size computation: http://www.statmethods.net/stats/power.html
# 1. Power calculations for paired-sample and two-sample t test (equal size)

## effect size d: difference of the means divided by the pooled standard deviation

##  e.g., means for group 1 and 2 are 0 and 10; variances are 15^2 and 17^2 (satisfy rule of thumb for equal variance): pooled standard deviation is sqrt((15^2 + 17^2)/2) = 16.03

# or if variances for two groups are equal (16^2), then use 16

# 1. Power calculations for balanced one-way analysis of variance tests 

pwr.t.test(d=(10-0)/16.03,power=.8,sig.level=.05,type="two.sample",alternative="two.sided")

pwr.t.test(d=(10-0)/16.03,power=.8,sig.level=.05,type="two.sample",alternative="greater")

# note: could determine power given sample size

pwr.t.test(d=(10-0)/16.03,n=20,sig.level=.05,type="two.sample",alternative="two.sided")


# 2. Power calculations for Balanced one-way analysis of variance (equal size)
# effect size f: see http://www.statmethods.net/stats/power.html

pwr.anova.test(k = 4, f = 0.2, sig.level = 0.05, power = 0.8)


