## repeated measures/longitudinal data: under each experimental design, the subjects are being measured multiple times

## The data called exer, consists of people who were randomly assigned to two different diets: low-fat and not low-fat and three different types of exercise: at rest, walking leisurely and running. 
#  Their pulse rate was measured at three different time points during their assigned exercise: at 1 minute, 15 minutes and 30 minutes.
# MAybe Multi-factor ANOVA?
# Factor A: diet
# Factor B: exercise type
# Factor C: time

exer <- read.csv("http://www.ats.ucla.edu/stat/data/exer.csv",header=TRUE)
head(exer)

## Convert variables to factor
exer <- within(exer, {
diet.f <- factor(diet,labels=c("low", "none-low"))
exertype.f <- factor(exertype,labels=c("rest","walking","running"))
time.f <- factor(time,labels=c("1-min","15-min","30-min"))
id <- factor(id)
})
print(exer)

# first consider the model including diet as the group variable in a one-way anova layout. 

with(exer, interaction.plot(time.f, diet.f, pulse,
  ylim = c(90, 110), lty = c(1, 12), lwd = 3,
  ylab = "mean of pulse", xlab = "time", trace.label = "diet"))

diet.aov <- aov(pulse ~ diet.f * time.f,
  data = exer)
summary(diet.aov)

## this model is not correct because it fail to adjust for the correlation across time (remember the independent assumption in ANOVA)
## That is, time is a within-subject variable by specifying Error(id)

diet.aov <- aov(pulse ~ diet.f * time.f + Error(id),
  data = exer)
summary(diet.aov)

# consider the model including exertype as the group variable.

with(exer, interaction.plot(time.f, exertype.f, pulse,
  ylim = c(80, 130), lty = c(1, 2, 4), lwd = 2,
  ylab = "mean of pulse", xlab = "time"), trace.label = "exercise type")

exertype.aov <- aov(pulse ~ exertype.f*time.f + Error(id/time.f), data = exer)
summary(exertype.aov)

## Looking at models including only the main effects of diet or exertype separately does not answer all our questions. 
## possible interaction effect of diet and exertype, and their interplay with time: need to adjust for a three-way interaction between diet, exertype and time.

with(exer, interaction.plot(time.f, diet.f:exertype.f, pulse,
  ylim = c(min(exer$pulse), max(exer$pulse)), lty = c(1:6), col=c(1:6),lwd = 3,
  ylab = "mean of pulse", xlab = "time", trace.label = "diet:exercise"))

## you have the option to specify time as categorical or continuous variable

## assuming linear trend

both.aov1 <- aov(pulse ~ exertype.f * diet.f * time + Error(id), data = exer)
summary(both.aov1)

## focus on specific time effect2 at 0, 15, 30 mins, i.e., not assuming any trends

both.aov2 <- aov(pulse ~ exertype.f * diet.f * time.f + Error(id), data = exer)
summary(both.aov2)

### Linear Mixed Effect (LME) Model approach for repeated measurements

## now we observe 4 time periods (unequally spaced) under the same design as above
## ANOVA model would not work in this scenario

exer2 <- read.csv("http://www.ats.ucla.edu/stat/data/study2.csv")
exer2 <- within(exer2, {
diet.f <- factor(diet,labels=c("low", "none-low"))
exertype.f <- factor(exertype,labels=c("rest","walking","running"))
id <- factor(id)
})
print(exer2)


library(lattice) ## offer many options

#spagetti plot to see the time trend

xyplot(pulse ~ time, data = exer2, groups = id,
  type = "o", panel = panel.superpose)

xyplot(pulse ~ time | exertype.f:diet.f, data = exer2, groups = id,
  type = "o", panel = panel.superpose)


## adjust for linear trend over time: a random intercept and random slope model 
## in LME model, you have the option to specify correlation structures for repeated measures

## level 1 pulse ~ b0 + b1*time + e
## level 2 b0 ~ diet.f*exertype.f + u0
## level 3 b1 ~ diet.f*exertype.f + u1
## combine 1,2,3: pulse ~ [diet.f*exertype.f*time] (fixed effect) + [u0 + u1*time](random effect) + e 


library(nlme)
fit1 <- lme(pulse ~ diet.f*exertype.f * time,
  random = list(id = pdDiag(~ time)), data = exer2)
summary(fit1)
anova(fit1)

## time and diet interaction is not significant 
## here assume equal correlation assumption among repeated measures: pdDiag(~ time)

fit2 <- lme(pulse ~ diet.f*exertype.f + exertype.f*time,
  random = list(id = pdDiag(~ time)), data = exer2)
summary(fit2)
anova(fit2)

## fit1 and fit3 specify the same model

fit3 <- aov(pulse ~ exertype.f*diet.f*time+ Error(id/time), data = exer2)
summary(fit3)
fit3


