


rm(list=ls()) #cleaning up memory
hmohiv<-read.table("http://www.ats.ucla.edu/stat/r/examples/asa/hmohiv.csv", sep=",", header = TRUE) 
head(hmohiv)

library(survival)

attach(hmohiv)

# Plot Kaplan Meier survival curve for both drug and no-drug group

# Kaplan–Meier estimate of the survival function: non-parametric (no distributional assumption required)

surv <- survfit( Surv(time, censor)~ strata(drug), data=hmohiv,conf.type="log") #confidence interval is calculated based on log(survival)
surv
plot(surv, lty=c(1,3), xlab="Time", ylab="Survival Probability (Kaplan-Meier Curve)")
legend(40, 1.0, c("Drug - No", "Drug - Yes") , lty=c(1,3))

# log-rank test (Mantel-Haenszel test): compare the survival distributions S(t)=P(T>t) of two samples without distributional assumptions

survdiff(Surv(time, censor) ~ drug, data=hmohiv, rho=0) #rho=1: Gehan-Wilcoxon test

survdiff(Surv(time, censor) ~ drug, data=hmohiv, rho=1) #rho=1: Gehan-Wilcoxon test

# treatment*age category
hmohiv$agecat <- cut(hmohiv$age, c(19.9, 29, 34, 39, 54.1))
surv <- survfit( Surv(time, censor)~ strata(agecat)+strata(drug), data=hmohiv, conf.type="log") 
surv
plot(surv, lty=c(6, 1, 4, 3), xlab="Time", ylab="Survival Probability")

survdiff(Surv(time, censor) ~ drug + agecat, data=hmohiv, rho=0) #rho=1: Gehan-Wilcoxon test

# cox proportional hazard model (semi-parametric): hazard function (a measure of risk of failure) h(t)=h0(t)exp(b0+b1*x1+ ... + bp*xp)

cox_fit=coxph(Surv(time, censor) ~ drug*agecat, data=hmohiv) 
summary(cox_fit)
summary(survfit(cox_fit))

# model diagnostic: proportional hazard assumption

# test
cox.zph(cox_fit)
# graphic check: log(-log(survival)) versus log of survival time graph should result in parallel curves

cox_fit=coxph(Surv(time, censor) ~ strata(drug) + strata(agecat), data=hmohiv) 
plot(survfit(cox_fit),col=c(1:8),fun="cumhaz")

#cox-snell residuals-a type of standardized residuals: should be a straight line

library(KMsurv)
coxsnellres=hmohiv$censor-resid(cox_fit,type="martingale")
# estimate the cumulative hazard function for residuals
fitres=survfit(coxph(Surv(coxsnellres,hmohiv$censor)~1,data=hmohiv))
plot(fitres$time,-log(fitres$surv),type='s',xlab='Cox-Snell Residuals', 
	ylab='Estimated Cumulative Hazard Function',
	main='The model fits the data reasonable well')
abline(0,1,col='red',lty=2)

# AFT model (parametric): e.g. log normal model: log(T) = b0+b1*x1+ ... + bp*xp + e, e iid Normal, where in likelihood those censored will contribute S(t)

fit_logn <- survreg(Surv(time, censor) ~ drug*agecat, data=hmohiv, dist='loggaussian')
summary(fit_logn)

# power analysis for survival data: has to make distributional assumption on survival time and depend on models
# see https://cran.r-project.org/web/packages/powerSurvEpi/powerSurvEpi.pdf