
# 
# We fit two-way ANOVA models in R using the function lm(). For example, the command: 
# > lm(Response ~ FactorA + FactorB) 
# fits a two-way ANOVA model without interactions. In contrast, the command 
# > lm(Response ~ FactorA + FactorB + FactorA*FactorB) 
# includes an interaction term. Here both FactorA and FactorB are categorical variables, while Response is quantitative. 


# We begin by reading in the data and making some exploratory plots of the data. 
# Factor A: filter type with levels "standard" and "octel"
# Factor B: car size with levels "small", "medium" or "large"
# response (continuous): noise levels


car <- read.table("http://www.stat.cmu.edu/~hseltman/309/Book/data/CarNoise.dat", header=TRUE)



# create labels for SIZE and TYPE variables in numerical orders
is.numeric(car$TYPE)
is.numeric(car$SIZE)



car$type.f=factor(car$TYPE, labels = c("standard", "octel"))
car$size.f=factor(car$SIZE, labels = c("small", "medium","large"))
head(car)



## test of normality and equal variance
## Fail due to small sample size or other covariates not properly adjusted 

with(car, tapply(NOISE,size.f:type.f,shapiro.test))

car_var=with(car, tapply(NOISE,size.f:type.f,var))
max(car_var)/min(car_var)


## Explorary Data Analysis 

#boxplot:
boxplot(NOISE ~ size.f:type.f,data=car)

### interaction plot
with(car,interaction.plot(x.factor=car$size.f,car$type.f,response=car$NOISE))


fit=lm(NOISE ~ as.factor(SIZE)*as.factor(TYPE),data=car)
anova(fit)

summary(fit)


